import { ActionCollectionConfig, StateSetter, StateConfigCallbackParam, StateChangesParam } from 'react-native-global-state-hooks';
import { GlobalStore } from './GlobalStore';
import { GlobalStoreConfig } from './GlobalStore.types';
/**
 * @description
 * Use this class to extends the capabilities of the GlobalStore.
 * by implementing the abstract methods onInitialize and onChange.
 * You can use this class to create a store with async storage.
 */
export declare abstract class GlobalStoreAbstract<TState, TMetadata = null, TStateSetter extends ActionCollectionConfig<TState, TMetadata> | StateSetter<TState> = StateSetter<TState>> extends GlobalStore<TState, TMetadata, TStateSetter> {
    constructor(state: TState, config?: GlobalStoreConfig<TState, TMetadata, TStateSetter>, actionsConfig?: TStateSetter | null);
    protected onInit: (parameters: StateConfigCallbackParam<TState, TMetadata, TStateSetter>) => void;
    protected onStateChanged: (parameters: StateChangesParam<TState, TMetadata, TStateSetter>) => void;
    protected abstract onInitialize: ({ setState, setMetadata, getMetadata, getState, actions, }: StateConfigCallbackParam<TState, TMetadata, TStateSetter>) => void;
    protected abstract onChange: ({ setState, setMetadata, getMetadata, getState, actions, }: StateChangesParam<TState, TMetadata, TStateSetter>) => void;
}
